@@ -17,7 +17,7 @@ import logging
 from pathlib import Path
 from sys import platform as opersys
 from sys import version_info
-from typing import Union
+from typing import List, Union
 
 # Imports depending on Python version
 if version_info[1] < 11:
@@ -27,6 +27,7 @@ else:
 
 # Package
 from qgis_deployment_toolbelt.constants import OS_CONFIG
+from qgis_deployment_toolbelt.plugins.plugin import QgisPlugin
 from qgis_deployment_toolbelt.utils.check_path import check_path
 
 # #############################################################################
@@ -43,6 +44,8 @@ logger = logging.getLogger(__name__)
 class QdtProfile:
     """Object definition for QGIS Profile handled by QDT."""
 
+    # optional mapping on attributes names.
+    # {attribute_name_in_output_object: attribute_name_from_input_file}
     ATTR_MAP = {
         "qgis_maximum_version": "qgisMaximumVersion",
         "qgis_minimum_version": "qgisMinimumVersion",
@@ -230,6 +233,17 @@ class QdtProfile:
         """
         return self._name
 
+    @property
+    def plugins(self) -> List[QgisPlugin]:
+        """Returns the plugins associated with the profile.
+
+        :return List[QgisPlugin]: list of plugins
+        """
+        if self._plugins:
+            return [QgisPlugin.from_dict(p) for p in self._plugins]
+        else:
+            return []
+
     @property
     def splash(self) -> Union[str, Path]:
         """Returns the profile splash image as path if can be resolved or as string.
@@ -252,3 +266,19 @@ class QdtProfile:
         :return str: profile version.
         """
         return self._version
+
+
+# #############################################################################
+# ##### Stand alone program ########
+# ##################################
+
+if __name__ == "__main__":
+    """Standalone execution."""
+    profile_good_sample = Path("tests/fixtures/profiles/good_profile_complete.json")
+    assert profile_good_sample.is_file() is True
+
+    qdt_profile = QdtProfile.from_json(
+        profile_json_path=profile_good_sample, profile_folder=profile_good_sample.parent
+    )
+    assert isinstance(qdt_profile, QdtProfile)
+    assert isinstance(qdt_profile.plugins, list)
